magneticalc.QMessageBox2.QMessageBox2

# ``magneticalc`.`QMessageBox2`.`QMessageBox2``

class documentation

`class QMessageBox2(QDialog2):`

Constructor: `QMessageBox2(title, text, icon, buttons, ...)`

View In Hierarchy

QMessageBox2 class.

Method | `__init__` | Initializes a message box.
Method | `accepting` | Sets the choice and accepts the dialog.
Method | `rejecting` | Gets called when the user hits the ESC key.
Instance Variable | `choice` | Undocumented

Inherited from `QDialog2`:

Method | `show` | Shows this dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted` (via `QDialog2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, title: `str`, text: `str`, icon, buttons, default_button):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`

Initializes a message box.

Parameters
title: `str` | Title
text: `str` | Text
icon | Icon
buttons | Buttons
default_button | Default button

def accepting(self, button_flag: `int`):

Sets the choice and accepts the dialog.

def rejecting(self):

Gets called when the user hits the ESC key.

choice =

Undocumented